This function pulls the latest EpiSewer docker image from the github container registry. This is necessary to use the docker backend for model fitting.
This function pulls the latest EpiSewer docker image from the github container registry. This is necessary to use the docker backend for model fitting.